#!/usr/bin/env bash

cd "$(dirname "$0")"

# turn on verbose debugging output for parabuild logs.
exec 4>&1; export BASH_XTRACEFD=4; set -x
# make errors fatal
set -e
# complain about unreferenced environment variables
set -u

if [ -z "$AUTOBUILD" ] ; then
    exit 1
fi

if [ "$OSTYPE" = "cygwin" ] ; then
    autobuild="$(cygpath -u $AUTOBUILD)"
else
    autobuild="$AUTOBUILD"
fi

top="$(pwd)"
stage="$top/stage"

# load autobuild provided shell functions and variables
source_environment_tempfile="$stage/source_environment.sh"
"$autobuild" source_environment > "$source_environment_tempfile"
. "$source_environment_tempfile"

CRASHPAD_SOURCE_DIR="crashpad"

version_str="8e85e6dd"

build=${AUTOBUILD_BUILD_ID:=0}
echo "${version_str}.${build}" > "${stage}/VERSION.txt"

# Fetch the library source
gclient config --name crashpad https://git.alchemyviewer.org/alchemy/thirdparty/crashpad/crashpad.git
gclient sync -r alchemy

pushd "$CRASHPAD_SOURCE_DIR"
    case "$AUTOBUILD_PLATFORM" in
        windows*)
            load_vsvars

            mkdir -p "$stage/lib/debug"
            mkdir -p "$stage/lib/release"

            if [ "$AUTOBUILD_ADDRSIZE" = 32 ]
            then
                targetcpu="x86"
            else
                targetcpu="x64"
            fi
            gn gen out/Debug --args=is_debug=true --args=target_cpu="$targetcpu"
            ninja -C out/Debug

            gn gen out/Release --args=is_debug=false --args=target_cpu="$targetcpu"
            ninja -C out/Release
        ;;

        darwin*)
            gn gen out/Debug --args=is_debug=true
            ninja -C out/Debug

            gn gen out/Release --args=is_debug=false
            ninja -C out/Release
        ;;

        linux*)
            # Default target per AUTOBUILD_ADDRSIZE
            opts="${TARGET_OPTS:--m$AUTOBUILD_ADDRSIZE -fPIC -DPIC}"

            # Handle any deliberate platform targeting
            if [ -z "${TARGET_CPPFLAGS:-}" ]; then
                # Remove sysroot contamination from build environment
                unset CPPFLAGS
            else
                # Incorporate special pre-processing flags
                export CPPFLAGS="${TARGET_CPPFLAGS:-}"
            fi

            if [ "$AUTOBUILD_ADDRSIZE" = 32 ]
            then
            else
            fi
        ;;
    esac
    mkdir -p "$stage/LICENSES"
    cp -a LICENSE "$stage/LICENSES/crashpad.txt"
popd
